==> ep-framework-gath-1.0.1-b66056.tar: src/Form/Element/MotorcycleModelSelect.php <==
<?php
namespace Ep\Gath\Form\Element;

use Ep\Gath\Gath;
use Zend\Form\Element\Select;

/**
 * Class ModelSelect
 *
 * @package Gath\Moto\Form\Element
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/gath-moto
 */
class MotorcycleModelSelect extends Select
{
    /** @var int */
    private $brandId;
    /** @var bool */
    protected $disableInArrayValidator = true;
    /** @var string */
    protected $emptyOption = 'Odaberite model';
    /** @var array */
    protected $valueOptions;
    /** @var Gath */
    protected $gath;

    /**
     * @param Gath $gath
     */
    public function setGath(Gath $gath): void
    {
        $this->gath = $gath;
    }

    /**
     * @return int
     */
    public function getBrandId(): int
    {
        return $this->brandId;
    }

    /**
     * @param int $brandId
     */
    public function setBrandId(int $brandId): void
    {
        if ($this->brandId !== $brandId) {
            $this->valueOptions = null;
        }

        $this->brandId = $brandId;
    }

    public function getAttribute($key)
    {
        return 'disabled' === $key ? null === $this->brandId : parent::getAttribute($key);
    }

    public function getAttributes()
    {
        $attributes = parent::getAttributes();

        if (null === $this->brandId) {
            $attributes['disabled'] = true;
        }

        return $attributes;
    }

    /**
     * @return array
     */
    public function getValueOptions()
    {
        if (null === $this->valueOptions) {
            $options = [];

            if (null !== $this->brandId) {
                $models = $this->gath->getMotorcycleModels($this->brandId);

                foreach ($models['Results'] as $model) {
                    $options[$model['ModelId']] = $model['ModelName'];
                }
            }

            $this->setValueOptions($options);
        }

        return parent::getValueOptions();
    }
}

==> ep-framework-gath-2.1.59-86a262.tar: src/Form/Element/MotorcycleModelSelect.php <==
<?php
namespace Ep\Gath\Form\Element;

use Ep\Gath\Gath;
use Laminas\Form\Element\Select;

/**
 * Class ModelSelect
 *
 * @package Gath\Moto\Form\Element
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/gath-moto
 */
class MotorcycleModelSelect extends Select
{
    /** @var int */
    private $brandId;
    /** @var bool */
    protected $disableInArrayValidator = true;
    /** @var string */
    protected $emptyOption = 'Odaberite model';
    /** @var array */
    protected $valueOptions;
    /** @var Gath */
    protected $gath;

    /**
     * @param Gath $gath
     */
    public function setGath(Gath $gath): void
    {
        $this->gath = $gath;
    }

    /**
     * @return int
     */
    public function getBrandId(): int
    {
        return $this->brandId;
    }

    /**
     * @param int $brandId
     */
    public function setBrandId(int $brandId): void
    {
        if ($this->brandId !== $brandId) {
            $this->valueOptions = null;
        }

        $this->brandId = $brandId;
    }

    public function getAttribute($key)
    {
        return 'disabled' === $key ? null === $this->brandId : parent::getAttribute($key);
    }

    public function getAttributes(): array
    {
        $attributes = parent::getAttributes();

        if (null === $this->brandId) {
            $attributes['disabled'] = true;
        }

        return $attributes;
    }

    /**
     * @return array
     */
    public function getValueOptions(): array
    {
        if (null === $this->valueOptions) {
            $options = [];

            if (null !== $this->brandId) {
                $models = $this->gath->getMotorcycleModels($this->brandId);

                foreach ($models['Results'] as $model) {
                    $options[$model['ModelId']] = $model['ModelName'];
                }
            }

            $this->setValueOptions($options);
        }

        return parent::getValueOptions();
    }
}
